package com.sun.org.apache.xml.internal.serializer;

import com.sun.org.apache.xml.internal.serializer.utils.WrappedRuntimeException;
import org.xml.sax.ContentHandler;
import com.sun.org.apache.xalan.internal.utils.ObjectFactory;
import com.sun.org.apache.xml.internal.serializer.utils.Utils;
import java.util.Properties;

public final class SerializerFactory
{
    private SerializerFactory() {
    }
    
    public static Serializer getSerializer(Properties format) {
        Serializer ser;
        try {
            String method = format.getProperty("method");
            if (method == null) {
                String msg2 = Utils.messages.createMessage("ER_FACTORY_PROPERTY_MISSING", new Object[] { "method" });
                throw new IllegalArgumentException(msg2);
            }
            String className = format.getProperty("{http://xml.apache.org/xalan}content-handler");
            if (null == className) {
                Properties methodDefaults = OutputPropertiesFactory.getDefaultMethodProperties(method);
                className = methodDefaults.getProperty("{http://xml.apache.org/xalan}content-handler");
                if (null == className) {
                    String msg = Utils.messages.createMessage("ER_FACTORY_PROPERTY_MISSING", new Object[] { "{http://xml.apache.org/xalan}content-handler" });
                    throw new IllegalArgumentException(msg);
                }
            }
            Class<Object> cls = ObjectFactory.findProviderClass(className, true);
            Object obj = cls.getConstructor(new Class[0]).newInstance(new Object[0]);
            if ((obj instanceof SerializationHandler)) {
                ser = (Serializer)obj;
                ser.setOutputFormat(format);
            }
            else if ((obj instanceof ContentHandler)) {
                className = "com.sun.org.apache.xml.internal.serializer.ToXMLSAXHandler";
                cls = ObjectFactory.findProviderClass(className, true);
                SerializationHandler sh = (SerializationHandler)cls.getConstructor(new Class[0]).newInstance(new Object[0]);
                sh.setContentHandler((ContentHandler)obj);
                sh.setOutputFormat(format);
                ser = sh;
            }
            else {
                throw new Exception(Utils.messages.createMessage("ER_SERIALIZER_NOT_CONTENTHANDLER", new Object[] { className }));
            }
        }
        catch (Exception e) {
            throw new WrappedRuntimeException(e);
        }
        return ser;
    }
}
